# Prod 20240235_v0.10.5_dec_931_dec_min_2924_dec_3476 

Base prod with missing declinations in `20240131_allsky_v0.10.5_all_dec_base` 

``` 
source /fefs/aswg/software/conda/etc/profile.d/conda.sh
conda activate lstchain-v0.10.5
lstmcpipe_generate_config PathConfigAllSkyFull --prod_id 20240131_allsky_v0.10.5_all_dec_base --dec_list dec_931 dec_min_2924 dec_3476 ``` 

contact: Thomas V.
